# cr-apk

Clash Royale APK Manager

## Usage

Installation:

```bash
pipx install cr-apk
```

List available commands:

```bash
> crapk list
```

```plaintext
Available commands:
  build   Builds an APK version
  deploy  Deploys an APK version
  help    Displays help for a command.
  list    Lists commands.
  ls      Lists all APK versions
  pull    Pulls an installed application's APKs from the device
```
